#!/usr/bin/perl
#
# Small Makefile to cat the needed sub_routines from ./src/
#
# Tue Jan 15 20:13:39 CET 2002 Martin J. Muench (mjm@remote-exploit.org)

# Oh yeah, be hard, be tough, just be #
use strict;

# Define needed variables #
my $source;
my @make;
my $i=0;

# OS Detection #

if ($^O =~ m/bsd/) { 

  # open(BSD), sometimes called OpenBSD by some kiddies ;-P
  open(BSD, '<src/bsd.h') || die "Cannot open bsd.h: $!\n";

  while(<BSD>) {
	chomp($_);
	$make[$i++]=$_;
  }
  close(BSD);
}

elsif ($^O =~ m/linux/) { 

  # open(Linux)
  open(LINUX, '<src/linux.h') || die "Cannot open linux.h: $!\n";

  while(<LINUX>) {
        chomp($_);
        $make[$i++]=$_;
  }
  close(LINUX);
}

else { print "OS unknown, mail author\n\n"; exit; }

# Open Outputfile and say hello #
open(WELLENREITER, '>Wellenreiter.pl') || die "Cannot open Outputfile: $!\n";
print "\nBuilding Wellenreiter for $^O\n\n";

# Cat content of every needed file into Outputfile #
foreach $source (@make) {

	print "Including file: $source\n";

	open(TEMP, "src/$source") || die "Cannot open Tempfile: $!\n";
	while(<TEMP>) { print WELLENREITER $_; } 
	close(TEMP);

}

# Say Good-bye #
print "\nSuccessfully build 'Wellenreiter.pl'\n\n";
close(WELLENREITER);


# Build the config-file '~/.wellenreiter.rc'


## Location of the configfile

my $conffile=%ENV->{HOME}."/.wellenreiter.rc";

## Function prototyping

sub bsd_conf;
sub linux_conf;
sub common;

##-- Begin of Main --##

## Welcome screen

print "\nWellenreiter config generator by team remote-exploit.org\n\n";
print "Press the return to continue\n"; sleep until <STDIN>;

## Create configfile

open(CONF, ">$conffile") || die "Error while opening config-file: $!";
print CONF "# Wellenreiter config-file, created by make-config\n\n";

if ($^O =~ m/bsd/) { 
	print "You are using BSD, if not please abort and drop me a mail\n\n";
	bsd_conf;
}

elsif ($^O =~ m/linux/) {
	print "You are using Linux, if not please abort and drop me a mail\n\n";
	linux_conf;
}

else { print "Unknown OS, try to build your config-file manually\n"; }

## Add the common stuff to configfile

common;

## Everythings done

close(CONF); exit(1);

##-- End of Main --##

## BSD_Conf

sub bsd_conf {

## We use BSD, yeah

# Get the interface
  print "Set your wireless interface [default: wi0] : ";
  chomp(my $device=<STDIN>);
  if(!$device) { print CONF "interface=wi0\n"; }
  else { print CONF "interface=$device\n"; }

# Get the path to wicontrol
  print "Set path to wicontrol [default: /usr/sbin/wicontrol] : ";
  chomp(my $path=<STDIN>);
  if(!$path) { print CONF "wicontrol=/usr/sbin/wicontrol\n"; }
  else { print CONF "wicontrol=$path\n"; }

# Fix the buttons
  print CONF "mwbuttons=Linkquality,Signallevel,Noiselevel,MISC-Stats,Card-Config,About\n";

# Enough for now, the rest is done by hand
  print "For more options, look at ~/.wellenreiter.rc\n\n";
  print "All necessary things are now configured\n\n";

}

## Linux_Conf

sub linux_conf {

## Well, lets use linux

# Get the interface
  print "\nSet your wireless interface used for getting statistics [default: eth1] : ";
  chomp(my $device=<STDIN>);
  if(!$device) { print CONF "interface=eth1\n"; }
  else { print CONF "interface=$device\n"; }

# Got compatible sniffing card ?
  print "\nDo u got a RAW-capture compatible card (read README) ? [y/n] [default: n] : ";
  chomp(my $got_raw_card=<STDIN>);
  if(!$got_raw_card || $got_raw_card eq 'n')
  { print CONF "got_raw_card=n\n"; }
  else 
  { 
  	print CONF "got_raw_card=y\n"; 
	  print "\nSet your wireless interface used for capturing raw data [default: eth2] : ";
	  chomp(my $sniffer_device=<STDIN>);
  	if(!$sniffer_device) 
  	{ 
  		print CONF "sniffer_device=eth2\n";
  	}
  	else 
  	{   print CONF "sniffer_device=$sniffer_device\n";
	  }

	  # Command to bring $sniffer_device into rfmon mode
	  print "\nCommand to bring the card into the raw mode %sniffer_device% is the device \n[default: echo \"Mode: r\" > /proc/driver/aironet/%sniffer_device%/Config && \n echo \"Mode: y\" > /proc/driver/aironet/%sniffer_device%/Config] : ";
	  my $start_sniff_command=<STDIN>;
  	chomp ($start_sniff_command);
	  if (!$start_sniff_command)
	  {
  		print CONF 'start_sniff_command=' . 'echo "Mode: r" > /proc/driver/aironet/%sniffer_device%/Config && echo "Mode: y" > /proc/driver/aironet/%sniffer_device%/Config'."\n";
  	}
  	else
  	{
		  print CONF 'start_sniff_command=' . $start_sniff_command . "\n";
	  }  	

	  # Command to stop $sniffer_device from rfmon mode
	  print "\nCommand to bring the card out of the raw mode %sniffer_device% is the device \n[default: echo \"Mode: ESS\" > /proc/driver/aironet/%sniffer_device%/Config] : ";
	  my $stop_sniff_command=<STDIN>;
  	chomp ($stop_sniff_command);
	  if (!$stop_sniff_command)
	  {
  		print CONF 'stop_sniff_command=' .'echo "Mode: ESS" > /proc/driver/aironet/%sniffer_device%/Config' . "\n";
  	}
  	else
  	{
		  print CONF 'stop_sniff_command=' . $stop_sniff_command . "\n";
	  }  	

	  # Command to swich the channel 
	  print "\nSwitch card channel command, %sniffer_device% is the device and %channel% the channel \n[default: echo \"Channel: %channel%\" > /proc/driver/aironet/%sniffer_device%/Config] : ";
	  my $channel_switch_command=<STDIN>;
  	chomp ($channel_switch_command);
	  if (!$channel_switch_command)
	  {
  		print CONF 'channel_switch_command=' .'echo "Channel: %channel%" > /proc/driver/aironet/%sniffer_device%/Config' . "\n";
  	}
  	else
  	{
		  print CONF 'channel_switch_command=' . $channel_switch_command . "\n";
	  }  	

	  # Get the path to ifconfig
	  print "\nSet path to ifconfig [default: /sbin/ifconfig]: ";
	  chomp(my $path_ifconfig=<STDIN>);
	  if(!$path_ifconfig) { print CONF "ifpath=/sbin/ifconfig\n"; }
	  else { print CONF "ifpath=$path_ifconfig\n"; }
  }

# Get the path to iwcontrol
  print "\nSet path to iwconfig [default: /sbin/iwconfig]: ";
  chomp(my $path=<STDIN>);
  if(!$path) { print CONF "iwpath=/sbin/iwconfig\n"; }
  else { print CONF "iwpath=$path\n"; }


# Do we use a small-screenres device like the Ipaq?
  print "\nActivate low-resolution? (only useful with Ipaq) [y/n] [default: n ]: ";
  chomp(my $ipaq=<STDIN>);
  if(!$ipaq || $ipaq eq 'y') 
  {
  	print CONF "lowres=y\n";
	  # Set the resolution
	  print CONF "screenwidth=320\n";
 	 print CONF "screenheight=240\n";
  }
  else
  {
  	print CONF "lowres=n\n";
  }

# Do u like to enable the audio features?
  print "\nActivate accoustic features? [y/n] [default: y ]: ";
  chomp(my $audio=<STDIN>);
  if(!$audio || $audio eq 'y') 
  {
  	print CONF "enable_audio=1\n";
		print "\nCommand to execute when a broadcasting network is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $broadfound =<STDIN>);
		if (!$broadfound || $broadfound eq 'printf "\a"' || $broadfound eq 'printf "\\a"')
		{
			print CONF "c_new_broadcast_netfound=printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_new_broadcast_netfound=$broadfound\n";
		}

		print "\nCommand to execute when a NON-broadcasting network is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $nbroadfound =<STDIN>);
		if (!$nbroadfound || $nbroadfound eq 'printf "\a"' || $nbroadfound eq 'printf "\\a"')
		{
			print CONF "c_new_nonbroadcast_netfound=printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_new_nonbroadcast_netfound=$nbroadfound\n";
		}

		print "\nCommand to execute when a new object is found? \ndefault [printf \"\\a\"] : ";
		chomp (my $nbjfound =<STDIN>);
		if (!$nbjfound || $nbjfound eq 'printf "\a"' || $nbjfound eq 'printf "\\a"')
		{
			print CONF "c_objectfound =printf \"\\a\"\n";
		}
		else
		{
			print CONF "c_objectfound=$nbjfound\n";
		}

		
  }
  else
  {
  	print CONF "enable_audio=0\n"
  }


# Fix the buttons
  print CONF "mwbuttons=Linkquality,Signallevel,Noiselevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,About\n";
  print CONF "mwbuttons_cisco=Linkquality,Signallevel,RX-Stats,TX-Stats,MISC-Stats,Card-Config,Scanner,Batterymon,About\n";

# Add path and dev
  print CONF "wirelessfile=/proc/net/wireless\n";
  print CONF "netstatsfile=/proc/net/dev\n";

# Enough for now, the rest is done by hand
  print "For more options, look at ~/.wellenreiter.rc\n\n";
  print "All necessary things are now configured\n\n";
  print "\n\tYou can now run perl Wellenreiter.pl\n\n\n";
}

## Add the common stuff to configfile

sub common {

print CONF qq~

#############################################################
### You can change the following parameters if you want ####
### to change the default layout of the windows, but    ###
### it should match for anyone. If you want to be safe  ##
### leave it as it is.                                  #
########################################################

#-- Mainwindow layout --#
#How many buttons to display in a single row on the mainwindow?
columncount=1

#-- Reiceive-Statistics-Window layout --#
rxcolumn=4
rxtitle=Receive-Statistics

#-- Send-Statistics-Window layout --#
txcolumn=4
txtitle=Send-Statistics

#-- MISC-Statistics-Window layout --#
misccolumn=4
misctitle=Misc-Statistics

#-- About-Window layout --#
abouttitle=About

#-- Config-Window layout --#
configtitle=Configuration
configcolumn=4

#-- Signallevel-Window layout --#
signaltitle=Signallevel

#-- Linkquality-Window layout --#
linktitle=Linkquality

#-- Noiselevel-Window layout --#
noisetitle=Noiselevel

##########################################################
###       Don't change anything below this line       ###
########################################################

#-- General definitions --#
progname=Wellenreiter
version=v0.8

#-- Linux-wireless-extension-path  -  This should be right for all--#
wirelessfile=/proc/net/wireless

#-- Netpackets statistics file  -  This should be right for all --#
netstatsfile=/proc/net/dev

##########################################################
###             End of the config file                ###
########################################################
~;

}




# EOF #
